@@ -7,12 +7,16 @@ namespace PhpMyAdmin\Controllers\Table;
 use PhpMyAdmin\Core;
 use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Gis\GisVisualization;
+use PhpMyAdmin\Html\Generator;
 use PhpMyAdmin\Message;
-use PhpMyAdmin\Response;
+use PhpMyAdmin\ResponseRenderer;
 use PhpMyAdmin\Template;
 use PhpMyAdmin\Url;
 use PhpMyAdmin\Util;
+
+use function __;
 use function array_merge;
+use function is_array;
 
 /**
  * Handles creation of the GIS visualizations.
@@ -25,26 +29,25 @@ final class GisVisualizationController extends AbstractController
     /** @var DatabaseInterface */
     private $dbi;
 
-    /**
-     * @param Response          $response
-     * @param string            $db       Database name.
-     * @param string            $table    Table name.
-     * @param DatabaseInterface $dbi
-     */
-    public function __construct($response, Template $template, $db, $table, $dbi)
-    {
+    public function __construct(
+        ResponseRenderer $response,
+        Template $template,
+        string $db,
+        string $table,
+        DatabaseInterface $dbi
+    ) {
         parent::__construct($response, $template, $db, $table);
         $this->dbi = $dbi;
     }
 
-    public function index(): void
+    public function __invoke(): void
     {
-        global $cfg, $url_params, $PMA_Theme, $db, $err_url;
+        global $cfg, $urlParams, $db, $errorUrl;
 
         Util::checkParameters(['db']);
 
-        $err_url = Util::getScriptNameForOption($cfg['DefaultTabDatabase'], 'database');
-        $err_url .= Url::getCommon(['db' => $db], '&');
+        $errorUrl = Util::getScriptNameForOption($cfg['DefaultTabDatabase'], 'database');
+        $errorUrl .= Url::getCommon(['db' => $db], '&');
 
         if (! $this->hasDatabase()) {
             return;
@@ -64,7 +67,7 @@ final class GisVisualizationController extends AbstractController
         if ($sqlQuery == '') {
             $this->response->setRequestStatus(false);
             $this->response->addHTML(
-                Message::error(__('No SQL query was set to fetch data.'))
+                Message::error(__('No SQL query was set to fetch data.'))->getDisplay()
             );
 
             return;
@@ -73,13 +76,16 @@ final class GisVisualizationController extends AbstractController
         // Execute the query and return the result
         $result = $this->dbi->tryQuery($sqlQuery);
         // Get the meta data of results
-        $meta = $this->dbi->getFieldsMeta($result);
+        $meta = [];
+        if ($result !== false) {
+            $meta = $this->dbi->getFieldsMeta($result);
+        }
 
         // Find the candidate fields for label column and spatial column
         $labelCandidates = [];
         $spatialCandidates = [];
         foreach ($meta as $column_meta) {
-            if ($column_meta->type === 'geometry') {
+            if ($column_meta->isMappedTypeGeometry) {
                 $spatialCandidates[] = $column_meta->name;
             } else {
                 $labelCandidates[] = $column_meta->name;
@@ -88,17 +94,18 @@ final class GisVisualizationController extends AbstractController
 
         // Get settings if any posted
         $visualizationSettings = [];
-        if (Core::isValid($_POST['visualizationSettings'], 'array')) {
+        // Download as PNG/SVG/PDF use _GET and the normal form uses _POST
+        if (isset($_POST['visualizationSettings']) && is_array($_POST['visualizationSettings'])) {
             $visualizationSettings = $_POST['visualizationSettings'];
+        } elseif (isset($_GET['visualizationSettings']) && is_array($_GET['visualizationSettings'])) {
+            $visualizationSettings = $_GET['visualizationSettings'];
         }
 
         // Check mysql version
         $visualizationSettings['mysqlVersion'] = $this->dbi->getVersion();
         $visualizationSettings['isMariaDB'] = $this->dbi->isMariaDB();
 
-        if (! isset($visualizationSettings['labelColumn'])
-            && isset($labelCandidates[0])
-        ) {
+        if (! isset($visualizationSettings['labelColumn']) && isset($labelCandidates[0])) {
             $visualizationSettings['labelColumn'] = '';
         }
 
@@ -107,23 +114,20 @@ final class GisVisualizationController extends AbstractController
             $visualizationSettings['spatialColumn'] = $spatialCandidates[0];
         }
 
+        // Download as PNG/SVG/PDF use _GET and the normal form uses _POST
         // Convert geometric columns from bytes to text.
-        $pos = $_GET['pos'] ?? $_SESSION['tmpval']['pos'];
-        if (isset($_GET['session_max_rows'])) {
-            $rows = $_GET['session_max_rows'];
+        $pos = (int) ($_POST['pos'] ?? $_GET['pos'] ?? $_SESSION['tmpval']['pos']);
+        if (isset($_POST['session_max_rows']) || isset($_GET['session_max_rows'])) {
+            $rows = (int) ($_POST['session_max_rows'] ?? $_GET['session_max_rows']);
         } else {
             if ($_SESSION['tmpval']['max_rows'] !== 'all') {
-                $rows = $_SESSION['tmpval']['max_rows'];
+                $rows = (int) $_SESSION['tmpval']['max_rows'];
             } else {
-                $rows = $GLOBALS['cfg']['MaxRows'];
+                $rows = (int) $GLOBALS['cfg']['MaxRows'];
             }
         }
-        $this->visualization = GisVisualization::get(
-            $sqlQuery,
-            $visualizationSettings,
-            $rows,
-            $pos
-        );
+
+        $this->visualization = GisVisualization::get($sqlQuery, $visualizationSettings, $rows, $pos);
 
         if (isset($_GET['saveToFile'])) {
             $this->saveToFile($visualizationSettings['spatialColumn'], $_GET['fileFormat']);
@@ -131,11 +135,7 @@ final class GisVisualizationController extends AbstractController
             return;
         }
 
-        $this->addScriptFiles([
-            'vendor/openlayers/OpenLayers.js',
-            'vendor/jquery/jquery.svg.js',
-            'table/gis_visualization.js',
-        ]);
+        $this->addScriptFiles(['vendor/openlayers/OpenLayers.js', 'table/gis_visualization.js']);
 
         // If all the rows contain SRID, use OpenStreetMaps on the initial loading.
         if (! isset($_POST['displayVisualization'])) {
@@ -160,31 +160,32 @@ final class GisVisualizationController extends AbstractController
         /**
          * Displays the page
          */
-        $url_params['goto'] = Util::getScriptNameForOption(
-            $cfg['DefaultTabDatabase'],
-            'database'
-        );
-        $url_params['back'] = Url::getFromRoute('/sql');
-        $url_params['sql_query'] = $sqlQuery;
-        $url_params['sql_signature'] = Core::signSqlQuery($sqlQuery);
+        $urlParams['goto'] = Util::getScriptNameForOption($cfg['DefaultTabDatabase'], 'database');
+        $urlParams['back'] = Url::getFromRoute('/sql');
+        $urlParams['sql_query'] = $sqlQuery;
+        $urlParams['sql_signature'] = Core::signSqlQuery($sqlQuery);
         $downloadUrl = Url::getFromRoute('/table/gis-visualization', array_merge(
-            $url_params,
+            $urlParams,
             [
                 'saveToFile' => true,
                 'session_max_rows' => $rows,
                 'pos' => $pos,
+                'visualizationSettings[spatialColumn]' => $visualizationSettings['spatialColumn'],
+                'visualizationSettings[labelColumn]' => $visualizationSettings['labelColumn'] ?? null,
             ]
         ));
+
+        $startAndNumberOfRowsFieldset = Generator::getStartAndNumberOfRowsFieldsetData($sqlQuery);
+
         $html = $this->template->render('table/gis_visualization/gis_visualization', [
-            'url_params' => $url_params,
+            'url_params' => $urlParams,
             'download_url' => $downloadUrl,
             'label_candidates' => $labelCandidates,
             'spatial_candidates' => $spatialCandidates,
             'visualization_settings' => $visualizationSettings,
-            'sql_query' => $sqlQuery,
+            'start_and_number_of_rows_fieldset' => $startAndNumberOfRowsFieldset,
             'visualization' => $this->visualization->toImage('svg'),
             'draw_ol' => $this->visualization->asOl(),
-            'theme_image_path' => $PMA_Theme->getImgPath(),
         ]);
 
         $this->response->addHTML($html);
