@@ -1,20 +1,16 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Functionality for the navigation tree
- *
- * @package PhpMyAdmin-Navigation
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Navigation\Nodes;
 
-use PhpMyAdmin\Util;
+use function __;
 
 /**
  * Represents a function node in the navigation tree
- *
- * @package PhpMyAdmin-Navigation
  */
 class NodeFunction extends NodeDatabaseChild
 {
@@ -29,16 +25,19 @@ class NodeFunction extends NodeDatabaseChild
     public function __construct($name, $type = Node::OBJECT, $isGroup = false)
     {
         parent::__construct($name, $type, $isGroup);
-        $this->icon = Util::getImage('b_routines', __('Function'));
+        $this->icon = ['image' => 'b_routines', 'title' => __('Function')];
         $this->links = [
-            'text' => 'db_routines.php?server=' . $GLOBALS['server']
-                . '&amp;db=%2$s&amp;item_name=%1$s&amp;item_type=FUNCTION'
-                . '&amp;edit_item=1',
-            'icon' => 'db_routines.php?server=' . $GLOBALS['server']
-                . '&amp;db=%2$s&amp;item_name=%1$s&amp;item_type=FUNCTION'
-                . '&amp;execute_dialog=1',
+            'text' => [
+                'route' => '/database/routines',
+                'params' => ['item_type' => 'FUNCTION', 'edit_item' => 1, 'db' => null, 'item_name' => null],
+            ],
+            'icon' => [
+                'route' => '/database/routines',
+                'params' => ['item_type' => 'FUNCTION', 'execute_dialog' => 1, 'db' => null, 'item_name' => null],
+            ],
         ];
         $this->classes = 'function';
+        $this->urlParamName = 'item_name';
     }
 
     /**
