@@ -7,9 +7,11 @@ declare(strict_types=1);
 
 namespace PhpMyAdmin\Plugins\Transformations\Abs;
 
+use PhpMyAdmin\FieldMetadata;
 use PhpMyAdmin\Plugins\TransformationsPlugin;
 use PhpMyAdmin\Url;
-use stdClass;
+
+use function __;
 use function array_merge;
 use function htmlspecialchars;
 
@@ -37,13 +39,13 @@ abstract class DownloadTransformationsPlugin extends TransformationsPlugin
     /**
      * Does the actual work of each specific transformations plugin.
      *
-     * @param string        $buffer  text to be transformed
-     * @param array         $options transformation options
-     * @param stdClass|null $meta    meta information
+     * @param string             $buffer  text to be transformed
+     * @param array              $options transformation options
+     * @param FieldMetadata|null $meta    meta information
      *
      * @return string
      */
-    public function applyTransformation($buffer, array $options = [], ?stdClass $meta = null)
+    public function applyTransformation($buffer, array $options = [], ?FieldMetadata $meta = null)
     {
         global $row, $fields_meta;
 
@@ -57,10 +59,12 @@ abstract class DownloadTransformationsPlugin extends TransformationsPlugin
                         break;
                     }
                 }
+
                 if (isset($pos)) {
                     $cn = $row[$pos];
                 }
             }
+
             if (empty($cn)) {
                 $cn = 'binary_file.dat';
             }
